All files type.ts

0% Statements 0/0
0% Branches 0/0
0% Functions 0/0
0% Lines 0/0

Press n or j to go to the next uncovered block, b, p or k for the previous block.

1 2 3 4 5 6           
export enum Envs {
  Dev = 'dev',
  Stage = 'stage',
  Prod = 'prod',
}